diff regression/regression-tests.bash @ 41:183ae993b9ad

security fix for potential buffer overrun in lz decompress
author carl
date Tue, 02 Oct 2007 15:49:44 -0700
parents 6fe121a971c9
children f6db1f060a95
line wrap: on
line diff
--- a/regression/regression-tests.bash	Fri Aug 24 18:57:59 2007 -0700
+++ b/regression/regression-tests.bash	Tue Oct 02 15:49:44 2007 -0700
@@ -1,22 +1,24 @@
 #!/bin/bash
 
+val="valgrind --leak-check=full"
+
 for i in {1..6}; do
     rm -rf output$i
     mkdir output$i
 done
 
-#   ../src/pst2ldif -b 'o=ams-cc.com, c=US' -c 'newPerson' ams.pst >ams.err
-#   ../src/readpst -cv    -o output1 ams.pst
-#   ../src/readpst -cl -r -o output2 ams.pst
-#   ../src/readpst -S     -o output3 ams.pst
-#   ../src/readpst -M     -o output4 ams.pst
-#   ../src/readpst        -o output5 mbmg.archive.pst
+$val  ../src/pst2ldif -b 'o=ams-cc.com, c=US' -c 'newPerson' ams.pst >ams.err  2>&1
+$val  ../src/readpst -cv    -o output1 ams.pst                       >out1.err 2>&1
+$val  ../src/readpst -cl -r -o output2 ams.pst                       >out2.err 2>&1
+$val  ../src/readpst -S     -o output3 ams.pst                       >out3.err 2>&1
+$val  ../src/readpst -M     -o output4 ams.pst                       >out4.err 2>&1
+$val  ../src/readpst        -o output5 mbmg.archive.pst              >out5.err 2>&1
+$val  ../src/readpst        -o output6 test.pst                      >out6.err 2>&1
 
-    ../src/readpst        -o output1 -d dumper ams.pst
-    ../src/readpstlog -f I dumper >dumperams.log
-
-#   touch /tmp/pam.pst
-#   ../src/readpst        -o output6 -d dumper /tmp/pam.pst
-#   ../src/readpstlog -f I dumper >dumperpam.log
+#   ../src/readpst        -o output1 -d dumper ams.pst
+#   ../src/readpstlog -f I dumper >dumperams.log
+#
+#   ../src/readpst        -o output6 -d dumper /tmp/test.pst
+#   ../src/readpstlog -f I dumper >dumpertest.log
 
     rm -f dumper